@@ -67,6 +67,7 @@ bool AppearanceGTK3::saveSettings(const QString& file) const
     flow3 << "gtk-theme-name=" << m_settings["theme"] << "\n";
     flow3 << "gtk-icon-theme-name="<< m_settings["icon"] << "\n";
     flow3 << "gtk-fallback-icon-theme=" << m_settings["icon_fallback"] << "\n";
+    flow3 << "gtk-cursor-theme-name=" << m_settings["cursor"] << "\n";
     flow3 << "gtk-toolbar-style=" << m_settings["toolbar_style"] << "\n";
     flow3 << "gtk-menu-images=" << m_settings["show_icons_menus"] << "\n";
     flow3 << "gtk-button-images=" << m_settings["show_icons_buttons"] << "\n";
@@ -94,6 +95,8 @@ bool AppearanceGTK3::loadSettings(const QString& path)
                 m_settings["icon"] = *it;
             else if (it.key() == "gtk-fallback-icon-theme")
                 m_settings["icon_fallback"] = *it;
+            else if (it.key() == "gtk-cursor-theme-name")
+                m_settings["cursor"] = *it;
             else if (it.key() == "gtk-font-name")
                 m_settings["font"] = *it;
             else if (it.key() == "gtk-toolbar-style")
